@@ -8,6 +8,7 @@ Run with (for example):
 """
 import sys
 import mido
+import time
 from mido import MidiFile
 
 filename = sys.argv[1]
@@ -18,9 +19,13 @@ else:
 
 with mido.open_output(portname) as output:
     try:
-        for message in MidiFile(filename).play():
+        midifile = MidiFile(filename)
+        t0 = time.time()
+        for message in midifile.play():
             print(message)
             output.send(message)
+        print('play time: {:.2f} s (expected {:.2f})'.format(
+                time.time() - t0, midifile.length))
 
     except KeyboardInterrupt:
         print()
