@@ -165,23 +165,24 @@ class Backend(object):
             return []
 
     def get_input_names(self, **kwargs):
-        """Return a sorted list of all input port names."""
+        """Return a list of all input port names."""
         devices = self._get_devices(**self._add_api(kwargs))
         names = [device['name'] for device in devices if device['is_input']]
-        return list(sorted(names))
+        return names
 
     def get_output_names(self, **kwargs):
-        """Return a sorted list of all output port names."""
+        """Return a list of all output port names."""
         devices = self._get_devices(**self._add_api(kwargs))
         names = [device['name'] for device in devices if device['is_output']]
-        return list(sorted(names))
+        return names
 
     def get_ioport_names(self, **kwargs):
-        """Return a sorted list of all I/O port names."""
+        """Return a list of all I/O port names."""
         devices = self._get_devices(**self._add_api(kwargs))
         inputs = [device['name'] for device in devices if device['is_input']]
-        outputs = [device['name'] for device in devices if device['is_output']]
-        return sorted(set(inputs) & set(outputs))
+        outputs = set(
+            [device['name'] for device in devices if device['is_output']])
+        return [name for name in inputs if name in outputs]
 
     def __repr__(self):
         if self.loaded:
