@@ -33,10 +33,10 @@ else:
 def get_devices(api=None, **kwargs):
     devices = []
 
-    input_names = set(rtmidi.MidiIn().ports)
-    output_names = set(rtmidi.MidiOut().ports)
+    input_names = rtmidi.MidiIn().ports
+    output_names = rtmidi.MidiOut().ports
 
-    for name in sorted(input_names | output_names):
+    for name in input_names + output_names:
         devices.append({'name': name,
                         'is_input': name in input_names,
                         'is_output': name in output_names,
