@@ -3,10 +3,6 @@ from .midifiles import MetaMessage, UnknownMetaMessage
 
 
 class Frozen(object):
-    def __repr__(self):
-        text = super(Frozen, self).__repr__()
-        return '<frozen {}'.format(text[1:])
-
     def __setattr__(self, *_):
         raise ValueError('frozen message is immutable')
 
@@ -23,7 +19,8 @@ class FrozenMetaMessage(Frozen, MetaMessage):
 
 
 class FrozenUnknownMetaMessage(Frozen, UnknownMetaMessage):
-    pass
+    def __repr__(self):
+        return 'Frozen' + UnknownMetaMessage.__repr__(self)
 
 
 def is_frozen(msg):
