@@ -1,5 +1,3 @@
-from collections import deque
-from numbers import Integral
 from .specs import (SYSEX_START, SYSEX_END,
                     SPEC_BY_STATUS, CHANNEL_MESSAGES,
                     MIN_PITCHWHEEL)
