@@ -12,10 +12,10 @@ class BaseMessage(object):
     is_meta = False
 
     def copy(self):
-        raise NotImplemented
+        raise NotImplementedError
 
     def bytes(self):
-        raise NotImplemented
+        raise NotImplementedError
 
     def bin(self):
         """Encode message and return as a bytearray.
@@ -54,11 +54,37 @@ class BaseMessage(object):
         """
         return cl(**data)
 
+    def _get_value_names(self):
+        # This is overriden by MetaMessage.
+        return list(SPEC_BY_TYPE[self.type]['value_names']) + ['time']
+
+    def __repr__(self):
+        items = [repr(self.type)]
+        for name in self._get_value_names():
+            items.append('{}={!r}'.format(name, getattr(self, name)))
+        return '{}({})'.format(type(self).__name__, ', '.join(items))
+
     @property
     def is_realtime(self):
         """True if the message is a system realtime message."""
         return self.type in REALTIME_TYPES
 
+    def is_cc(self, control=None):
+        """Return True if the message is of type 'control_change'.
+
+        The optional control argument can be used to test for a specific
+        control number, for example:
+
+        if msg.is_cc(7):
+            # Message is control change 7 (channel volume).
+        """
+        if self.type != 'control_change':
+            return False
+        elif control is None:
+            return True
+        else:
+            return self.control == control
+
     def __delattr__(self, name):
         raise AttributeError('attribute cannot be deleted')
 
@@ -162,9 +188,6 @@ class Message(BaseMessage):
     def __str__(self):
         return msg2str(vars(self))
 
-    def __repr__(self):
-        return '<message {}>'.format(str(self))
-
     def _setattr(self, name, value):
         if name == 'type':
             raise AttributeError('type attribute is read only')
